atwinc1500-rs
Description
This is a driver for the atwinc1500 network controller written in pure Rust. The primary targets for this driver are boards like the Adafruit Feather M0 Wifi or the Adafruit Atwinc1500 Breakout. The roadmap below describes what is currently working.
Table of Contents
Roadmap
This roadmap is subject to change.
-
Info/Hardware
- Gpio control
- Read mac address
- Read firmware version
-
Wifi
- Scan
-
Connect
- Older connection format
- Newer connection format
- Open network
- WEP (WEP is deprecated in later atwinc firmware versions)
- Wpa2
- Wpa2 Enterprise
- Disconnect from network
- Read RSSI
- AP Mode
-
TcpFullStack
- bind
- listen
- accept
-
TcpClientStack
- socket
- connect
- is_connected
- send
- receive
- close
- Crypto
- SSL
- OTA
- ATE Mode
- UART
Installation
Add this crate to your Cargo.toml:
atwinc1500 = "0.1.0"Usage
Examples can be found here.
Documentation
License
Licensed under either of
- Apache License, Version 2.0 (LICENSE-APACHE or http://www.apache.org/licenses/LICENSE-2.0)
- MIT license (LICENSE-MIT or http://opensource.org/licenses/MIT)
at your option.
Contribution
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in the work by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.
Modules
- error
- Atwinc1500 error definitions
- gpio
- Atwinc1500 gpio related members
- socket
- Socket related members
- types
- Public type implementations
- wifi
- Wifi connection items
Structs
- Atwinc1500
- Atwin1500 driver struct